'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stageFile = exports.getChangedFiles = exports.getSinceRevision = exports.detect = exports.name = undefined;

var _findUp = require('find-up');

var _findUp2 = _interopRequireDefault(_findUp);

var _execa = require('execa');

var _execa2 = _interopRequireDefault(_execa);

var _path = require('path');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const name = exports.name = 'git';

const detect = exports.detect = directory => {
  const gitDirectory = _findUp2.default.sync('.git', { cwd: directory });
  if (gitDirectory) {
    return (0, _path.dirname)(gitDirectory);
  }
};

const runGit = (directory, args) => _execa2.default.sync('git', args, {
  cwd: directory
});

const getLines = execaResult => execaResult.stdout.split('\n');

const getSinceRevision = exports.getSinceRevision = (directory, { staged }) => {
  const revision = staged ? 'HEAD' : runGit(directory, ['merge-base', 'HEAD', 'master']).stdout.trim();
  return runGit(directory, ['rev-parse', '--short', revision]).stdout.trim();
};

const getChangedFiles = exports.getChangedFiles = (directory, revision, staged) => {
  return (staged ? getLines(runGit(directory, ['diff', '--name-only', '--cached', revision])) : [...getLines(runGit(directory, ['diff', '--name-only', '--diff-filter=ACMRTUB', revision])), ...getLines(runGit(directory, ['ls-files', '--others', '--exclude-standard']))]).filter(Boolean);
};

const stageFile = exports.stageFile = (directory, file) => {
  runGit(directory, ['add', file]);
};